[GRASS-SVN] r63851 - in grass/trunk/lib: gis imagery

svn_grass at osgeo.org svn_grass at osgeo.org
Mon Dec 29 11:25:41 PST 2014


Author: martinl
Date: 2014-12-29 11:25:41 -0800 (Mon, 29 Dec 2014)
New Revision: 63851

Modified:
   grass/trunk/lib/gis/color_rules.c
   grass/trunk/lib/gis/list.c
   grass/trunk/lib/gis/ls.c
   grass/trunk/lib/imagery/list_subgp.c
Log:
libgis: G__ls -> G_ls2


Modified: grass/trunk/lib/gis/color_rules.c
===================================================================
--- grass/trunk/lib/gis/color_rules.c	2014-12-29 19:18:18 UTC (rev 63850)
+++ grass/trunk/lib/gis/color_rules.c	2014-12-29 19:25:41 UTC (rev 63851)
@@ -112,7 +112,7 @@
 
     G_snprintf(path, GPATH_MAX, "%s/etc/colors", G_gisbase());
 
-    rules = G__ls(path, nrules);
+    rules = G_ls2(path, nrules);
 
     rules = G_realloc(rules, (*nrules + 3) * sizeof (const char *));
 

Modified: grass/trunk/lib/gis/list.c
===================================================================
--- grass/trunk/lib/gis/list.c	2014-12-29 19:18:18 UTC (rev 63850)
+++ grass/trunk/lib/gis/list.c	2014-12-29 19:25:41 UTC (rev 63851)
@@ -126,7 +126,7 @@
      * otherwise the ls must be forced into columnar form.
      */
 
-    list = G__ls(path, &count);
+    list = G_ls2(path, &count);
 
     if (count > 0) {
 	fprintf(out, _("%s files available in mapset <%s>:\n"), desc, mapset);

Modified: grass/trunk/lib/gis/ls.c
===================================================================
--- grass/trunk/lib/imagery/list_subgp.c	2014-12-29 19:18:18 UTC (rev 63850)
+++ grass/trunk/lib/imagery/list_subgp.c	2014-12-29 19:25:41 UTC (rev 63851)
@@ -47,7 +47,7 @@
     if (!G_lstat(path, &sb) == 0 || !S_ISDIR(sb.st_mode))
 	return NULL;
 
-    subgs = G__ls(path, subgs_num);
+    subgs = G_ls2(path, subgs_num);
     return subgs;
 }
 



More information about the grass-commit mailing list
--- grass/trunk/lib/gis/ls.c	2014-12-29 19:18:18 UTC (rev 63850)
+++ grass/trunk/lib/gis/ls.c	2014-12-29 19:25:41 UTC (rev 63851)
@@ -52,10 +52,10 @@
 }
 
 /**
  * \brief Sets a function and its complementary data for G__ls filtering.
  *
  * Defines a filter function and its rule data that allow G__ls to filter out
  * unwanted file names.  Call this function before G__ls.
  *
  * \param func      Filter callback function to compare a file name and closure
  * 		    pattern (if NULL, no filter will be used).
@@ -92,7 +92,7 @@
  * \return          Pointer to array of strings containing the listing
  **/
 
-char **G__ls(const char *dir, int *num_files)
+char **G_ls2(const char *dir, int *num_files)
 {
     struct dirent *dp;
     DIR *dfd;
@@ -136,7 +136,7 @@
 void G_ls(const char *dir, FILE * stream)
 {
     int i, n;
-    char **dir_listing = G__ls(dir, &n);
+    char **dir_listing = G_ls2(dir, &n);
 
     G_ls_format(dir_listing, n, 0, stream);
 
@@ -52,10 +52,10 @@
 
 /**
- * \brief Sets a function and its complementary data for G__ls filtering.
+ * \brief Sets a function and its complementary data for G_ls2 filtering.
  *
@@ -52,10 +52,10 @@
  *
- * Defines a filter function and its rule data that allow G__ls to filter out
- * unwanted file names.  Call this function before G__ls.
+ * Defines a filter function and its rule data that allow G_ls2 to filter out
+ * unwanted file names.  Call this function before G_ls2.
  *
  * \param func      Filter callback function to compare a file name and closure

Modified: grass/trunk/lib/imagery/list_subgp.c
===================================================================